| packageSkeletonForR-package | R Documentation |
A GitHub based package skeleton for R. The repo includes the package skeleton, yml and markdown to produce a static website using additional R packages (packagePages and centerPackageTemplate)
| Package: | packageSkeletonForR |
| Type: | Package |
| Version: | 0.0-0.1 |
| Date: | 2022-04-21 |
| License: | GPL-3 |
| LazyLoad: | yes |
Damian W. Betebenner DBetebenner@nciea.org
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.